==> kotlin-web-site-ui-4.1.0-alpha.4.tgz: package/out/components/header/header.js <==
import React__default, { forwardRef, useState, useMemo, useRef, useImperativeHandle, useLayoutEffect, useCallback, useEffect } from 'react';
import { ThemeProvider } from '@rescui/ui-contexts';
import FocusManager from '@rescui/focus-manager';
import useResizeObserver from '@react-hook/resize-observer';
import OutsideClickHandler from 'react-outside-click-handler';
import { LogoLarge } from './logo-large/logo-large.js';
import styles from './header.module.pcss.js';
import { getNavScheme } from './nav-scheme.js';
import { HorizontalMenu } from './horizontal-menu/horizontal-menu.js';
import { SearchButton } from './search-button/search-button.js';
import { SearchBox } from './search-box/search-box.js';
import { MenuPopup } from './menu-popup/menu-popup.js';
import { LogoSmall } from './logo-small/logo-small.js';
import classNames from 'classnames';
import { SearchWrapper } from './search-wrapper/search-wrapper.js';
import { isMacOs } from './is-macos.js';
import { KEY_K_CODE } from './key-codes.js';
const MENU_POPUP_BREAKPOINT = 640;
const Header = forwardRef(({
  productWebUrl,
  hasSearch = false,
  currentUrl,
  currentTitle,
  className,
  hasBorder = true,
  dropdownTheme = 'dark',
  linkHandler,
  isPlayground,
  isUrlActive,
  searchConfig
}, forwardedRef) => {
  const [menuPopupExpanded, setMenuPopupExpanded] = useState(false);
  const [isMenuPopupVisible, setIsMenuPopupVisible] = useState(false);
  const [isSearchBoxVisible, setSearchBoxVisible] = useState(false);
  const [fullSearchActive, setFullSearchActive] = useState(false);
  const items = useMemo(() => getNavScheme(isUrlActive, currentUrl, isPlayground), [isUrlActive, currentUrl, isPlayground]);
  const headerRef = useRef(null);
  useImperativeHandle(forwardedRef, () => headerRef.current);
  useLayoutEffect(() => {
    setIsMenuPopupVisible((headerRef.current?.getBoundingClientRect?.().width ?? 0) <= MENU_POPUP_BREAKPOINT);
  }, [headerRef]);
  useResizeObserver(headerRef, entry => setIsMenuPopupVisible(entry.contentRect.width <= MENU_POPUP_BREAKPOINT));
  const handleSearchButtonClick = useCallback(() => {
    setSearchBoxVisible(!isSearchBoxVisible);
  }, []);
  const handleSearchClose = useCallback(() => {
    setSearchBoxVisible(false);
    setFullSearchActive(false);
  }, []);
  const fullSearchKeyHandler = useCallback(event => {
    const isMacOsHotkeyPressed = isMacOs() && event.keyCode === KEY_K_CODE && event.metaKey;
    const isOtherPlatformsHotkeyPressed = !isMacOs() && event.keyCode === KEY_K_CODE && event.ctrlKey;

    if (isMacOsHotkeyPressed || isOtherPlatformsHotkeyPressed) {
      event.preventDefault();
      event.stopPropagation();
      setSearchBoxVisible(true);
      setFullSearchActive(true);
    }
  }, []);
  useEffect(() => {
    if (typeof document !== `undefined`) {
      document.addEventListener('keydown', fullSearchKeyHandler);
      const focusManager = new FocusManager();
      return () => {
        document.removeEventListener('keydown', fullSearchKeyHandler);
        focusManager.destroy();
      };
    }
  }, [fullSearchKeyHandler]);
  return React__default.createElement(ThemeProvider, {
    theme: 'dark'
  }, React__default.createElement(SearchWrapper, {
    searchConfig: searchConfig
  }, React__default.createElement("header", {
    ref: headerRef,
    className: classNames(styles.headerMenu, className, {
      [styles.withMenuPopup]: menuPopupExpanded,
      [styles.border]: hasBorder
    })
  }, isMenuPopupVisible && currentTitle && currentUrl && !menuPopupExpanded ? React__default.createElement(LogoSmall, {
    homeTitle: currentTitle,
    homeUrl: currentUrl
  }) : React__default.createElement(LogoLarge, {
    productWebUrl: productWebUrl
  }), isSearchBoxVisible ? React__default.createElement(OutsideClickHandler, {
    onOutsideClick: handleSearchClose
  }, React__default.createElement(SearchBox, {
    closeHandler: handleSearchClose,
    isMobile: isMenuPopupVisible,
    fullSearchActive: fullSearchActive,
    setFullSearchActive: setFullSearchActive
  })) : React__default.createElement(React__default.Fragment, null, !isMenuPopupVisible && React__default.createElement(HorizontalMenu, {
    items: items,
    theme: dropdownTheme,
    linkHandler: linkHandler
  }), React__default.createElement(SearchButton, {
    onClick: handleSearchButtonClick,
    isActive: hasSearch
  }), isMenuPopupVisible && React__default.createElement(MenuPopup, {
    items: items,
    setExpand: setMenuPopupExpanded,
    isExpanded: menuPopupExpanded,
    headerRef: headerRef,
    linkHandler: linkHandler
  })))));
});
export { Header };

==> kotlin-web-site-ui-4.2.0-alpha.4.tgz: package/out/components/header/header.js <==
import React__default, { forwardRef, useState, useMemo, useRef, useImperativeHandle, useLayoutEffect, useCallback, useEffect } from 'react';
import { ThemeProvider } from '@rescui/ui-contexts';
import FocusManager from '@rescui/focus-manager';
import OutsideClickHandler from 'react-outside-click-handler';
import { LogoLarge } from './logo-large/logo-large.js';
import styles from './header.module.pcss.js';
import { getNavScheme } from './nav-scheme.js';
import { HorizontalMenu } from './horizontal-menu/horizontal-menu.js';
import { SearchButton } from './search-button/search-button.js';
import { SearchBox } from './search-box/search-box.js';
import { MenuPopup } from './menu-popup/menu-popup.js';
import { LogoSmall } from './logo-small/logo-small.js';
import classNames from 'classnames';
import { SearchWrapper } from './search-wrapper/search-wrapper.js';
import { isMacOs } from './is-macos.js';
import { KEY_K_CODE } from './key-codes.js';
import useResizeObserver from '@react-hook/resize-observer';
const BREAKPOINT_XS = 640;
const Header = forwardRef(({
  productWebUrl,
  hasSearch = false,
  currentUrl,
  currentTitle,
  className,
  hasBorder = true,
  dropdownTheme = 'dark',
  linkHandler,
  isPlayground,
  isUrlActive,
  searchConfig
}, forwardedRef) => {
  const [menuPopupExpanded, setMenuPopupExpanded] = useState(false);
  const [isSearchBoxVisible, setSearchBoxVisible] = useState(false);
  const [fullSearchActive, setFullSearchActive] = useState(false);
  const items = useMemo(() => getNavScheme(isUrlActive, currentUrl, isPlayground), [isUrlActive, currentUrl, isPlayground]);
  const itemsWithoutHomeSection = useMemo(() => items.slice(1), [items]);
  const headerRef = useRef(null);
  useImperativeHandle(forwardedRef, () => headerRef.current);
  const [isMenuPopupVisible, setMenuPopupVisible] = useState(false);
  useLayoutEffect(() => {
    setMenuPopupVisible((headerRef.current?.getBoundingClientRect?.().width ?? 0) <= BREAKPOINT_XS);
  }, [headerRef]);
  useResizeObserver(headerRef, entry => setMenuPopupVisible(entry.contentRect.width <= BREAKPOINT_XS));
  const handleSearchButtonClick = useCallback(() => {
    setSearchBoxVisible(!isSearchBoxVisible);
  }, []);
  const handleSearchClose = useCallback(() => {
    setSearchBoxVisible(false);
    setFullSearchActive(false);
  }, []);
  const fullSearchKeyHandler = useCallback(event => {
    const isMacOsHotkeyPressed = isMacOs() && event.keyCode === KEY_K_CODE && event.metaKey;
    const isOtherPlatformsHotkeyPressed = !isMacOs() && event.keyCode === KEY_K_CODE && event.ctrlKey;

    if (isMacOsHotkeyPressed || isOtherPlatformsHotkeyPressed) {
      event.preventDefault();
      event.stopPropagation();
      setSearchBoxVisible(true);
      setFullSearchActive(true);
    }
  }, []);
  useEffect(() => {
    if (typeof document !== `undefined`) {
      document.addEventListener('keydown', fullSearchKeyHandler);
      const focusManager = new FocusManager();
      return () => {
        document.removeEventListener('keydown', fullSearchKeyHandler);
        focusManager.destroy();
      };
    }
  }, [fullSearchKeyHandler]);
  return React__default.createElement(ThemeProvider, {
    theme: 'dark'
  }, React__default.createElement(SearchWrapper, {
    searchConfig: searchConfig
  }, React__default.createElement("header", {
    ref: headerRef,
    className: classNames(styles.headerMenu, className, {
      [styles.withMenuPopup]: menuPopupExpanded,
      [styles.border]: hasBorder || menuPopupExpanded
    }),
    "data-test": 'header'
  }, isMenuPopupVisible && currentTitle && currentUrl && !menuPopupExpanded ? React__default.createElement(LogoSmall, {
    homeTitle: currentTitle,
    homeUrl: currentUrl
  }) : React__default.createElement(LogoLarge, {
    productWebUrl: productWebUrl
  }), isSearchBoxVisible ? React__default.createElement(OutsideClickHandler, {
    onOutsideClick: handleSearchClose
  }, React__default.createElement(SearchBox, {
    closeHandler: handleSearchClose,
    isMobile: isMenuPopupVisible,
    fullSearchActive: fullSearchActive,
    setFullSearchActive: setFullSearchActive
  })) : React__default.createElement(React__default.Fragment, null, !isMenuPopupVisible && React__default.createElement(HorizontalMenu, {
    items: itemsWithoutHomeSection,
    theme: dropdownTheme,
    linkHandler: linkHandler
  }), !menuPopupExpanded && React__default.createElement(SearchButton, {
    onClick: handleSearchButtonClick,
    isActive: hasSearch
  }), isMenuPopupVisible && React__default.createElement(MenuPopup, {
    items: items,
    setExpand: setMenuPopupExpanded,
    isExpanded: menuPopupExpanded,
    headerRef: headerRef,
    linkHandler: linkHandler
  })))));
});
export { Header };
